%define upstream_name    Math-Prime-Util
%define upstream_version 0.73

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 4

Summary:    Utilities related to prime numbers, including fast sieves and factoring
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        http://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Math/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(Carp)
BuildRequires: perl(Config)
BuildRequires: perl(Exporter) >= 5.570.0
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(Math::BigFloat) >= 1.590.0
BuildRequires: perl(Math::BigInt) >= 1.880.0
BuildRequires: perl(Math::Prime::Util::GMP) >= 0.500.0
BuildRequires: perl(Test::More) >= 0.450.0
BuildRequires: perl(Tie::Array)
BuildRequires: perl(XSLoader) >= 0.10.0
BuildRequires: perl(base)
BuildRequires: perl(bignum) >= 0.220.0
BuildRequires: perl(constant)
BuildRequires: perl-devel
%description
A set of utilities related to prime numbers. These include multiple sieving
methods, is_prime, prime_count, nth_prime, approximations and bounds for
the prime_count and nth prime, next_prime and prev_prime, factoring
utilities, and more.

The default sieving and factoring are intended to be (and currently are)
the fastest on CPAN, including the Math::Prime::XS manpage, the
Math::Prime::FastSieve manpage, the Math::Factor::XS manpage, the
Math::Prime::TiedArray manpage, the Math::Big::Factors manpage, the
Math::Factoring manpage, and the Math::Primality manpage (when the GMP
module is available). For numbers in the 10-20 digit range, it is often
orders of magnitude faster. Typically it is faster than the Math::Pari
manpage for 64-bit operations.

All operations support both Perl UV's (32-bit or 64-bit) and bignums. If
you want high performance with big numbers (larger than Perl's native
32-bit or 64-bit size), you should install the Math::Prime::Util::GMP
manpage and the Math::BigInt::GMP manpage. This will be a recurring theme
throughout this documentation -- while all bignum operations are supported
in pure Perl, most methods will be much slower than the C+GMP alternative.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}
%autopatch -p1

%build
%__perl Makefile.PL INSTALLDIRS=vendor

%make_build

%check
%make_build test

%install
%make_install

%files
%doc Changes LICENSE META.json META.yml MYMETA.yml README TODO examples
%{_bindir}/factor.pl
%{_bindir}/primes.pl
%{_mandir}/man3/*
%{perl_vendorarch}/*


%changelog
* Wed Jun 17 2020 umeabot <umeabot> 0.730.0-4.mga8
+ Revision: 1594923
- Rebuild for perl 5.32

* Sat Feb 15 2020 umeabot <umeabot> 0.730.0-3.mga8
+ Revision: 1529142
- Mageia 8 Mass Rebuild

* Tue Aug 27 2019 tv <tv> 0.730.0-2.mga8
+ Revision: 1433157
- rebuild with perl-5.30

* Fri Nov 16 2018 tv <tv> 0.730.0-1.mga7
+ Revision: 1330083
- update to 0.73

* Sat Nov 10 2018 tv <tv> 0.720.0-1.mga7
+ Revision: 1329396
- update to 0.72

* Fri Sep 21 2018 umeabot <umeabot> 0.710.0-2.mga7
+ Revision: 1293436
- Mageia 7 Mass Rebuild

* Thu Aug 30 2018 tv <tv> 0.710.0-1.mga7
+ Revision: 1255779
- update to 0.71

* Wed Aug 08 2018 pterjan <pterjan> 0.700.0-2.mga7
+ Revision: 1249792
- Rebuild for perl 5.28

* Sun Dec 03 2017 tv <tv> 0.700.0-1.mga7
+ Revision: 1180853
- update to 0.70
- update to 0.69

* Sat Nov 11 2017 tv <tv> 0.690.0-1.mga7
+ Revision: 1176900
- new release
- remove no more needed patch

* Tue Oct 24 2017 shlomif <shlomif> 0.680.0-1.mga7
+ Revision: 1173396
- update to 0.68

* Tue Oct 03 2017 tv <tv> 0.670.0-2.mga7
+ Revision: 1165400
- rebuild with fixed rpm for missing autodeps

* Sun Sep 24 2017 tv <tv> 0.670.0-1.mga7
+ Revision: 1158554
- update to 0.67

* Tue Sep 19 2017 tv <tv> 0.660.0-1.mga7
+ Revision: 1155773
- update to 0.66

* Thu Aug 31 2017 pterjan <pterjan> 0.650.0-2.mga7
+ Revision: 1149852
- Rebuild for perl ABI changes

* Mon Jul 24 2017 tv <tv> 0.650.0-1.mga7
+ Revision: 1130034
- patch 0: fix SIGFPE, Arithmetic exception in testsuite
- new release
- rebuild for perl 5.26
+ neoclust <neoclust>
- Rebuild against new Perl 5.26

* Sat May 28 2016 shlomif <shlomif> 0.580.0-1.mga6
+ Revision: 1019230
- New version 0.58

* Mon Jan 04 2016 shlomif <shlomif> 0.570.0-1.mga6
+ Revision: 919638
- update to 0.57

* Thu Dec 17 2015 shlomif <shlomif> 0.560.0-1.mga6
+ Revision: 911342
- update to 0.56

* Sat Oct 24 2015 shlomif <shlomif> 0.550.0-1.mga6
+ Revision: 894994
- update to 0.55

* Sun Sep 06 2015 sander85 <sander85> 0.530.0-1.mga6
+ Revision: 873528
- update to 0.53

* Thu Aug 13 2015 sander85 <sander85> 0.520.0-1.mga6
+ Revision: 864412
- update to 0.52

* Fri Jun 26 2015 tv <tv> 0.510.0-2.mga6
+ Revision: 845006
- rebuild for soname-ifed perl

* Tue Jun 23 2015 shlomif <shlomif> 0.510.0-1.mga6
+ Revision: 840714
- New version 0.51 + Rebuild for the new perl

* Sun Oct 19 2014 umeabot <umeabot> 0.430.0-4.mga5
+ Revision: 790403
- Rebuild to potentially add missing dependencies

* Wed Oct 15 2014 umeabot <umeabot> 0.430.0-3.mga5
+ Revision: 745641
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.430.0-2.mga5
+ Revision: 685372
- Mageia 5 Mass Rebuild

* Sat Aug 16 2014 sander85 <sander85> 0.430.0-1.mga5
+ Revision: 664337
- update to 0.43

* Sat Jun 21 2014 sander85 <sander85> 0.420.0-1.mga5
+ Revision: 638351
- update to 0.42

* Tue Jun 03 2014 pterjan <pterjan> 0.410.0-2.mga5
+ Revision: 631449
- Rebuild for perl 5.20

* Tue May 20 2014 sander85 <sander85> 0.410.0-1.mga5
+ Revision: 624508
- update to 0.41

* Fri Apr 25 2014 shlomif <shlomif> 0.400.0-1.mga5
+ Revision: 617859
- New version 0.40 tarball
- New version 0.40

* Sun Mar 30 2014 shlomif <shlomif> 0.390.0-1.mga5
+ Revision: 610438
- New version 0.39
- imported package perl-Math-Prime-Util


* Thu Feb 27 2014 cpan2dist 0.37-1mga
- initial mageia release, generated with cpan2dist
